package com.academiaandroid.autenticacion;

//Ejemplo aplicacin Android que permite sincronizar automticamente 
//con una base de datos remota, de manera peridica, usando un Sync Adapter
//
//academiaandroid.com
//
//by Jos Antonio Gzquez Rodrguez



import java.util.Date;
import android.accounts.Account;
import android.app.Activity;
import android.content.ContentResolver;
import android.graphics.Color;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

public class MainActivity extends Activity {

	//Declaramos los componentes y variables necesarias para la lgica de la aplicacin. 
	public static final String AUTHORITY = "com.academiaandroid.autenticacion.SyncAdapter";
	public static final long SEGUNDOS = 5;
	private TextView txtDatos;
	private CheckBox checkSync;
	private Button btnArrancar;
	private Button btnParar;
	private ImageView imgRojo;
	private ImageView imgAmarillo;
	private ImageView imgVerde;
	private TextView txtFecha;
	Account mAccount = null;
	Date date = null;
	MiSyncAdapter syncadapter;
	static ContentResolver content = null;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        //Enlazamos los componentes con los recursos definidos a nivel de layout.
        txtDatos = (TextView)findViewById(R.id.txtDatos);
        checkSync = (CheckBox)findViewById(R.id.checkSync);
        btnArrancar = (Button)findViewById(R.id.btnArrancar);
        btnParar = (Button)findViewById(R.id.btnParar);
        txtFecha = (TextView)findViewById(R.id.txtFecha);
        imgRojo = (ImageView)findViewById(R.id.imgRojo);
        imgAmarillo = (ImageView)findViewById(R.id.imgAmarillo);
        imgVerde = (ImageView)findViewById(R.id.imgVerde);
        mAccount = new Account("MiSyncService", "com.academiaandroid.autenticacion.SyncAdapter");  
        
        //Evento lanzado cuando cambia el estado del checkbox
        //definido para sincronizar de manera peridica con el servidor remoto.
        checkSync.setOnCheckedChangeListener(new OnCheckedChangeListener() {
			
			@Override
			public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
				if(isChecked)
		    	{	
					Bundle params = new Bundle();
			        params.putBoolean(ContentResolver.SYNC_EXTRAS_EXPEDITED, false);
			        params.putBoolean(ContentResolver.SYNC_EXTRAS_DO_NOT_RETRY, false);
			        params.putBoolean(ContentResolver.SYNC_EXTRAS_MANUAL, false);
		    		content = getContentResolver();
		    		ContentResolver.addPeriodicSync(mAccount, AUTHORITY, params, 5);		    		
		    		Toast.makeText(getApplicationContext(),"Sincronizacin Automtica ON", Toast.LENGTH_LONG).show();
		            btnArrancar.setVisibility(View.INVISIBLE);
		            btnParar.setVisibility(View.INVISIBLE);
		            imgRojo.setVisibility(View.INVISIBLE);
		            imgVerde.setVisibility(View.INVISIBLE);
		            imgAmarillo.setVisibility(View.VISIBLE);
		            txtFecha.setTextColor(Color.RED);
		            txtFecha.setText(new Date().toString());
		            
		    	}else
		    	{
		    		btnArrancar.setVisibility(View.VISIBLE);
		            btnParar.setVisibility(View.VISIBLE);
		            imgRojo.setVisibility(View.VISIBLE);
		            imgVerde.setVisibility(View.VISIBLE);
		            imgAmarillo.setVisibility(View.VISIBLE);
		            Toast.makeText(getApplicationContext(), "Sincronizacin Automtica OFF", Toast.LENGTH_LONG).show();
		    	}				
			}
		});
    }  

    //Evento On Click que abre una conexin con el servidor remoto,
    //mostrando el ltimo registro introducido en la Base de Datos.
    public void iniciarConexion(View v)
    {
    	Toast.makeText(this, "Conexin iniciada con Servidor Remoto", Toast.LENGTH_LONG).show();
    	TareaAsincrona tarea = new TareaAsincrona(v,this);
    	tarea.execute();  
    	imgRojo.setVisibility(View.INVISIBLE);
        imgAmarillo.setVisibility(View.INVISIBLE);
        imgVerde.setVisibility(View.VISIBLE);
        txtFecha.setTextColor(Color.RED);
        txtFecha.setText(new Date().toString());
    }
    
    //Evento On Click que cierra la conexin con el servidor remoto.
    public void detenerConexion(View v)
    {
    	TareaAsincrona tarea = new TareaAsincrona(v,this);
    	tarea.cancel(true);     	
        txtDatos.setText("Sin Datos (Conexin detenida)");
        txtDatos.setTextColor(Color.RED);
        imgVerde.setVisibility(View.INVISIBLE);
        imgAmarillo.setVisibility(View.INVISIBLE);
        imgRojo.setVisibility(View.VISIBLE);
    }
}
