package com.academiaandroid.autenticacion;

//Ejemplo aplicacin Android que permite sincronizar automticamente 
//con una base de datos remota, de manera peridica, usando un Sync Adapter
//
//academiaandroid.com
//
//by Jos Antonio Gzquez Rodrguez


import android.accounts.Account;
import android.app.Service;
import android.content.AbstractThreadedSyncAdapter;
import android.content.ContentProviderClient;
import android.content.ContentResolver;
import android.content.Intent;
import android.content.SyncResult;
import android.os.Bundle;
import android.os.IBinder;
import android.view.View;

//Clase que hereda de Service para ejecutar aplicaciones de larga duracin en segundo plano.
public class MiSyncService extends Service{

	private static MiSyncAdapter syncAdapter = null;
	private static final Object syncAdapterLock = new Object();
	private MainActivity mContext;
	
	public MiSyncService(MainActivity context)
	{
		super();
		mContext = context;
	}
	
	//El sistema realizada la llamada a este mtodo cuando se crea el servicio por primera vez.
	@Override
    public void onCreate() {
        synchronized (syncAdapterLock) {
            if (syncAdapter == null)
            	syncAdapter = new MiSyncAdapter(mContext);
        }               
    }
 
    @Override
    public IBinder onBind(Intent intent) {
        return syncAdapter.getSyncAdapterBinder();
    }
}

//Clase que hereda de AbstractThreadedSyncAdapter para la sincronizacin de operaciones.
class MiSyncAdapter extends AbstractThreadedSyncAdapter{

	ContentResolver mContentResolver;
	private MainActivity main;
	private TareaAsincrona tareas;
	private View v;
	
	public MiSyncAdapter(MainActivity context) {
		
		super(context, true);		
		main = context;
		mContentResolver = context.getContentResolver();

	}

	//Mtodo que permite la sincronizacin de esta cuenta.
	@Override
	public void onPerformSync(Account account, Bundle extras, String authority,
								ContentProviderClient provider, SyncResult syncResult) {
		try{	
			System.out.println("En onPerformSync");
			tareas = new TareaAsincrona(v, main);
			tareas.execute();			
		}catch(Exception ex)
		{
			System.out.println("Error en onPerformSync: " + ex.getMessage());
		}	
	}
}
